import logging

from odoo import Command
from odoo.tests import TransactionCase, tagged, new_test_user


_logger = logging.getLogger(__name__)


@tagged('post_install', '-at_install')
class TestMergeToPo(TransactionCase):
    @classmethod
    def setUpClass(cls):
        super().setUpClass()

        cls.supplier = new_test_user(cls.env, login='supplier', groups='base.group_portal')
        cls.product1 = cls.env['product.product'].create({
            'name': "Product 1",
        })
        cls.product2 = cls.env['product.product'].create({
            'name': "Product 2",
        })

        cls.purchase_order1 = cls.env['purchase.order'].create({
            'partner_id': cls.supplier.partner_id.id,
            'order_line': [
                Command.create({
                    'name': "po1 line1",
                    'product_id': cls.product1.id,
                    'product_qty': 1,
                    'price_unit': 10,
                }),
            ],
        })
        cls.purchase_order2 = cls.env['purchase.order'].create({
            'partner_id': cls.supplier.partner_id.id,
            'order_line': [
                Command.create({
                    'name': "po2 line1",
                    'product_id': cls.product2.id,
                    'product_qty': 1,
                    'price_unit': 10,
                }),
            ],
        })

    def test_simple_case(self):
        self.purchase_order1._merge_to_po(self.purchase_order2)

        self.assertFalse(self.purchase_order1.order_line)
        self.assertRecordValues(self.purchase_order2.order_line, [
            {'name': "po1 line1", 'product_id': self.product1.id, 'product_qty': 1, 'price_unit': 10},
            {'name': "po2 line1", 'product_id': self.product2.id, 'product_qty': 1, 'price_unit': 10},
        ])

    def test_products_with_seller_info(self):
        self.product1.write({
            'seller_ids': [Command.create({
                'partner_id': self.supplier.partner_id.id,
                'price': 20,
            })],
        })

        self.purchase_order1._merge_to_po(self.purchase_order2)

        self.assertFalse(self.purchase_order1.order_line)
        self.assertRecordValues(self.purchase_order2.order_line, [
            {'name': "po2 line1", 'product_id': self.product2.id, 'product_qty': 1, 'price_unit': 10},
            {'name': "po1 line1", 'product_id': self.product1.id, 'product_qty': 1, 'price_unit': 10},
        ])
